[niepce] Color -> Colour. en_CA.



commit b2865123c0e7bbb181aae50d13ddc17d4d8ad6c6
Author: Hubert Figuière <hub figuiere net>
Date:   Sun Feb 3 22:02:01 2013 -0500

    Color -> Colour. en_CA.

 src/engine/db/label.hpp                |   20 +++++++-------
 src/engine/db/library.cpp              |   18 +++++++-------
 src/engine/db/library.hpp              |    8 +++---
 src/fwk/base/Makefile.am               |    2 +-
 src/fwk/base/{color.cpp => colour.cpp} |   12 ++++----
 src/fwk/base/{color.hpp => colour.hpp} |   16 ++++++------
 src/fwk/toolkit/gdkutils.cpp           |   18 +++++++-------
 src/fwk/toolkit/gdkutils.hpp           |   11 ++++----
 src/libraryclient/uidataprovider.cpp   |   12 ++++----
 src/libraryclient/uidataprovider.hpp   |    4 +-
 src/niepce/ui/dialogs/editlabels.cpp   |   42 ++++++++++++++++----------------
 src/niepce/ui/dialogs/editlabels.hpp   |    4 +-
 src/niepce/ui/librarycellrenderer.cpp  |   40 +++++++++++++++---------------
 src/niepce/ui/niepcewindow.cpp         |   10 ++++----
 14 files changed, 108 insertions(+), 109 deletions(-)
---
diff --git a/src/engine/db/label.hpp b/src/engine/db/label.hpp
index dd2137b..79f4f1a 100644
--- a/src/engine/db/label.hpp
+++ b/src/engine/db/label.hpp
@@ -26,7 +26,7 @@
 
 #include <tr1/memory>
 
-#include "fwk/base/color.hpp"
+#include "fwk/base/colour.hpp"
 #include "engine/db/librarytypes.hpp"
 
 namespace eng {
@@ -41,27 +41,27 @@ public:
     typedef std::vector<Ptr> List;
     typedef std::tr1::shared_ptr<List> ListPtr;
 
-    Label(library_id_t _id, const std::string & _label, const std::string & _colorstring)
+    Label(library_id_t _id, const std::string & _label, const std::string & _colourstring)
         : m_id(_id), m_label(_label)
-        , m_color(_colorstring)
+        , m_colour(_colourstring)
         {
         }
-               
+
     library_id_t id() const
         { return m_id; }
-    const std::string & label() 
+    const std::string & label()
         { return m_label; }
     void set_label(const std::string & l)
         { m_label = l; }
-    const fwk::RgbColor & color() const
-        { return m_color; }
-    void set_color(const fwk::RgbColor & c)
-        { m_color = c; }
+    const fwk::RgbColour & colour() const
+        { return m_colour; }
+    void set_colour(const fwk::RgbColour & c)
+        { m_colour = c; }
 
 private:
     library_id_t          m_id;
     std::string      m_label;
-    fwk::RgbColor    m_color;
+    fwk::RgbColour    m_colour;
 };
 
 }
diff --git a/src/engine/db/library.cpp b/src/engine/db/library.cpp
index 2c581d2..48c20c9 100644
--- a/src/engine/db/library.cpp
+++ b/src/engine/db/library.cpp
@@ -27,7 +27,7 @@
 
 #include <glibmm/i18n.h>
 
-#include "fwk/base/color.hpp"
+#include "fwk/base/colour.hpp"
 #include "niepce/notifications.hpp"
 #include "library.hpp"
 #include "metadata.hpp"
@@ -804,11 +804,11 @@ void Library::getAllLabels(const Label::ListPtr & l)
             while(m_dbdrv->read_next_row()) {
                 int32_t id;
                 std::string name;
-                std::string color;
+                std::string colour;
                 m_dbdrv->get_column_content(0, id);
                 m_dbdrv->get_column_content(1, name);
-                m_dbdrv->get_column_content(2, color);
-                l->push_back(Label::Ptr(new Label(id, name, color)));
+                m_dbdrv->get_column_content(2, colour);
+                l->push_back(Label::Ptr(new Label(id, name, colour)));
             }
         }
     }
@@ -819,13 +819,13 @@ void Library::getAllLabels(const Label::ListPtr & l)
 }
 
 
-library_id_t Library::addLabel(const std::string & name, const std::string & color)
+library_id_t Library::addLabel(const std::string & name, const std::string & colour)
 {
     library_id_t ret = -1;
 
     SQLStatement sql(boost::format("INSERT INTO labels (name,color)"
                                    " VALUES ('%1%', '%2%')") 
-                     % name % color);
+                     % name % colour);
     if(m_dbdrv->execute_statement(sql)) {
         library_id_t id = m_dbdrv->last_row_id();
         DBG_OUT("last row inserted %d", (int)id);
@@ -835,17 +835,17 @@ library_id_t Library::addLabel(const std::string & name, const std::string & col
 }
 
 
-library_id_t Library::addLabel(const std::string & name, const fwk::RgbColor & c)
+library_id_t Library::addLabel(const std::string & name, const fwk::RgbColour & c)
 {
     return addLabel(name, c.to_string());
 }
 
 
-bool Library::updateLabel(library_id_t label_id, const std::string & name, const std::string & color)
+bool Library::updateLabel(library_id_t label_id, const std::string & name, const std::string & colour)
 {
     SQLStatement sql(boost::format("UPDATE labels SET name='%2%', color='%3%'"
                                    " WHERE id='%1%';") 
-                     % label_id % name % color);
+                     % label_id % name % colour);
     try {
         return m_dbdrv->execute_statement(sql);
     }
diff --git a/src/engine/db/library.hpp b/src/engine/db/library.hpp
index 59e9013..97a2bdc 100644
--- a/src/engine/db/library.hpp
+++ b/src/engine/db/library.hpp
@@ -43,7 +43,7 @@
 #define DB_SCHEMA_VERSION 5
 
 namespace fwk {
-class RgbColor;
+class RgbColour;
 }
 
 namespace eng {
@@ -169,9 +169,9 @@ public:
     bool moveFileToFolder(library_id_t file_id, library_id_t folder_id);
 
                void getAllLabels(const eng::Label::ListPtr & l);
-    library_id_t addLabel(const std::string & name, const std::string & color);
-    library_id_t addLabel(const std::string & name, const fwk::RgbColor & c);
-    bool updateLabel(library_id_t label_id, const std::string & name, const std::string & color);
+    library_id_t addLabel(const std::string & name, const std::string & colour);
+    library_id_t addLabel(const std::string & name, const fwk::RgbColour & c);
+    bool updateLabel(library_id_t label_id, const std::string & name, const std::string & colour);
     bool deleteLabel(library_id_t label_id);
 
     /** Trigger the processing of the XMP update queue */
diff --git a/src/fwk/base/Makefile.am b/src/fwk/base/Makefile.am
index d5105df..2a6be56 100644
--- a/src/fwk/base/Makefile.am
+++ b/src/fwk/base/Makefile.am
@@ -28,7 +28,7 @@ testfractions_LDADD = libfwkbase.a \
        @LIBGLIBMM_LIBS@
 
 
-libfwkbase_a_SOURCES = color.hpp color.cpp \
+libfwkbase_a_SOURCES = colour.hpp colour.cpp \
        autoflag.hpp \
        date.hpp date.cpp \
        debug.hpp debug.cpp \
diff --git a/src/fwk/base/color.cpp b/src/fwk/base/colour.cpp
similarity index 85%
rename from src/fwk/base/color.cpp
rename to src/fwk/base/colour.cpp
index 2d4d398..ba2e6cf 100644
--- a/src/fwk/base/color.cpp
+++ b/src/fwk/base/colour.cpp
@@ -1,5 +1,5 @@
 /*
- * niepce - fwk/base/color.hpp
+ * niepce - fwk/base/colour.hpp
  *
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -25,12 +25,12 @@
 #include <boost/format.hpp>
 #include <boost/lexical_cast.hpp>
 
-#include "fwk/base/color.hpp"
+#include "fwk/base/colour.hpp"
 
 namespace fwk {
 
 
-  RgbColor::RgbColor(value_type r, value_type g, value_type b)
+  RgbColour::RgbColour(value_type r, value_type g, value_type b)
   {
     at(0) = r;
     at(1) = g;
@@ -38,7 +38,7 @@ namespace fwk {
   }
 
 
-  RgbColor::RgbColor(const std::string & s)
+  RgbColour::RgbColour(const std::string & s)
   {
     std::vector<std::string> components;
     boost::split(components, s, boost::is_any_of(" "));
@@ -56,11 +56,11 @@ namespace fwk {
     // fallback in case of failure
     at(0) = 0;
     at(1) = 0;
-    at(2) = 0;      
+    at(2) = 0;
   }
 
 
-  std::string RgbColor::to_string() const
+  std::string RgbColour::to_string() const
   {
     return str(boost::format("%1% %2% %3%") % at(0) % at(1) % at(2));
   }
diff --git a/src/fwk/toolkit/gdkutils.cpp b/src/fwk/toolkit/gdkutils.cpp
index 729e829..67f06d4 100644
--- a/src/fwk/toolkit/gdkutils.cpp
+++ b/src/fwk/toolkit/gdkutils.cpp
@@ -69,10 +69,10 @@ namespace fwk {
                        break;
                case 7:
                        pixbuf =  tmp->rotate_simple(Gdk::PIXBUF_ROTATE_COUNTERCLOCKWISE)->flip(FALSE);
-                       break;          
+                       break;
                case 8:
                        pixbuf =  tmp->rotate_simple(Gdk::PIXBUF_ROTATE_COUNTERCLOCKWISE);
-                       break;          
+                       break;
                default:
                        break;
                }
@@ -80,18 +80,18 @@ namespace fwk {
        }
 
 
-  Gdk::RGBA rgbcolor_to_gdkcolor(const fwk::RgbColor & color)
+  Gdk::RGBA rgbcolour_to_gdkcolor(const fwk::RgbColour & colour)
   {
-    Gdk::RGBA gdkcolor;
-    gdkcolor.set_rgba_u(color[0], color[1], color[2]);
-    return gdkcolor;
+    Gdk::RGBA gdkcolour;
+    gdkcolour.set_rgba_u(colour[0], colour[1], colour[2]);
+    return gdkcolour;
   }
 
 
-  fwk::RgbColor gdkcolor_to_rgbcolor(const Gdk::RGBA & color)
+  fwk::RgbColour gdkcolor_to_rgbcolour(const Gdk::RGBA & colour)
   {
-    fwk::RgbColor rgbcolor(color.get_red_u(), color.get_green_u(), color.get_blue_u());
-    return rgbcolor;
+    fwk::RgbColour rgbcolour(colour.get_red_u(), colour.get_green_u(), colour.get_blue_u());
+    return rgbcolour;
   }
 
 
diff --git a/src/fwk/toolkit/gdkutils.hpp b/src/fwk/toolkit/gdkutils.hpp
index bd8d16e..092ca85 100644
--- a/src/fwk/toolkit/gdkutils.hpp
+++ b/src/fwk/toolkit/gdkutils.hpp
@@ -24,11 +24,11 @@
 #include <gdkmm/pixbuf.h>
 #include <gdkmm/rgba.h>
 
-#include "fwk/base/color.hpp"
+#include "fwk/base/colour.hpp"
 
 namespace fwk {
-       
-       /** scale the pixbuf to fit in the square 
+
+       /** scale the pixbuf to fit in the square
         * @param dim the dimension of the square
         */
        Glib::RefPtr<Gdk::Pixbuf> gdkpixbuf_scale_to_fit(const Glib::RefPtr<Gdk::Pixbuf> & pix,
@@ -37,9 +37,8 @@ namespace fwk {
        Glib::RefPtr<Gdk::Pixbuf> gdkpixbuf_exif_rotate(const Glib::RefPtr<Gdk::Pixbuf> & pixbuf,
                                                                                                        int 
exif_orientation);
 
-  Gdk::RGBA rgbcolor_to_gdkcolor(const fwk::RgbColor & color);
-  fwk::RgbColor gdkcolor_to_rgbcolor(const Gdk::RGBA & color);
-
+  Gdk::RGBA rgbcolour_to_gdkcolor(const fwk::RgbColour & colour);
+  fwk::RgbColour gdkcolor_to_rgbcolour(const Gdk::RGBA & colour);
 }
 
 #endif
diff --git a/src/libraryclient/uidataprovider.cpp b/src/libraryclient/uidataprovider.cpp
index b3840a7..996f6c7 100644
--- a/src/libraryclient/uidataprovider.cpp
+++ b/src/libraryclient/uidataprovider.cpp
@@ -21,7 +21,7 @@
 #include <boost/bind.hpp>
 
 #include "fwk/base/debug.hpp"
-#include "fwk/base/color.hpp"
+#include "fwk/base/colour.hpp"
 #include "engine/db/label.hpp"
 #include "uidataprovider.hpp"
 
@@ -33,10 +33,10 @@ void UIDataProvider::updateLabel(const eng::Label::Ptr & l)
     // TODO: will work as long as we have 5 labels or something.
     for(eng::Label::List::iterator iter = m_labels.begin();
         iter != m_labels.end(); ++iter) {
-        
+
         if((*iter)->id() == l->id()) {
             (*iter)->set_label(l->label());
-            (*iter)->set_color(l->color());
+            (*iter)->set_colour(l->colour());
         }
     }
 }
@@ -56,7 +56,7 @@ void UIDataProvider::deleteLabel(int id)
     // TODO: will work as long as we have 5 labels or something.
     for(eng::Label::List::iterator iter = m_labels.begin();
         iter != m_labels.end(); ++iter) {
-        
+
         if((*iter)->id() == id) {
             DBG_OUT("remove label %d", id);
             iter = m_labels.erase(iter);
@@ -65,12 +65,12 @@ void UIDataProvider::deleteLabel(int id)
     }
 }
 
-const fwk::RgbColor * UIDataProvider::colorForLabel(int id) const
+const fwk::RgbColour * UIDataProvider::colourForLabel(int id) const
 {
     for(eng::Label::List::const_iterator iter = m_labels.begin();
         iter != m_labels.end(); ++iter) {
         if((*iter)->id() == id) {
-            return &((*iter)->color());
+            return &((*iter)->colour());
         }
     }
     return NULL;
diff --git a/src/libraryclient/uidataprovider.hpp b/src/libraryclient/uidataprovider.hpp
index e9203c3..a828ac5 100644
--- a/src/libraryclient/uidataprovider.hpp
+++ b/src/libraryclient/uidataprovider.hpp
@@ -25,7 +25,7 @@
 #include "engine/db/label.hpp"
 
 namespace fwk {
-class RgbColor;
+class RgbColour;
 }
 
 namespace libraryclient {
@@ -38,7 +38,7 @@ public:
     void updateLabel(const eng::Label::Ptr &);
     void addLabels(const eng::Label::ListPtr & l);
     void deleteLabel(int id);
-    const fwk::RgbColor * colorForLabel(int id) const;
+    const fwk::RgbColour * colourForLabel(int id) const;
     const eng::Label::List & getLabels() const
         { return m_labels; }
 private:
diff --git a/src/niepce/ui/dialogs/editlabels.cpp b/src/niepce/ui/dialogs/editlabels.cpp
index ec7ddbe..1402774 100644
--- a/src/niepce/ui/dialogs/editlabels.cpp
+++ b/src/niepce/ui/dialogs/editlabels.cpp
@@ -56,27 +56,27 @@ void EditLabels::setup_widget()
 
     add_header(_("Edit Labels"));
 
-    const char * color_fmt = "colorbutton%1%";
+    const char * colour_fmt = "colorbutton%1%";
     const char * value_fmt = "value%1%";
     for(size_t i = 0; i < 5; i++) {
         bool has_label = m_labels.size() > i;
 
-        Gtk::ColorButton *colorbutton;
+        Gtk::ColorButton *colourbutton;
         Gtk::Entry *labelentry;
 
-        _builder->get_widget(str(boost::format(color_fmt) % (i+1)), colorbutton);
-        m_colors[i] = colorbutton;
+        _builder->get_widget(str(boost::format(colour_fmt) % (i+1)), colourbutton);
+        m_colours[i] = colourbutton;
         _builder->get_widget(str(boost::format(value_fmt) % (i+1)), labelentry);
         DBG_ASSERT(labelentry, "couldn't find label");
         m_entries[i] = labelentry;
 
         if(has_label) {
-            Gdk::RGBA color = fwk::rgbcolor_to_gdkcolor(m_labels[i]->color());
-            colorbutton->set_rgba(color);
+            Gdk::RGBA colour = fwk::rgbcolour_to_gdkcolor(m_labels[i]->colour());
+            colourbutton->set_rgba(colour);
             labelentry->set_text(m_labels[i]->label());
         }
-        colorbutton->signal_color_set().connect(
-            sigc::bind(sigc::mem_fun(*this, &EditLabels::label_color_changed), i));
+        colourbutton->signal_color_set().connect(
+            sigc::bind(sigc::mem_fun(*this, &EditLabels::label_colour_changed), i));
         labelentry->signal_changed().connect(
             sigc::bind(sigc::mem_fun(*this, &EditLabels::label_name_changed), i));
     }
@@ -90,7 +90,7 @@ void EditLabels::label_name_changed(size_t idx)
 }
 
 
-void EditLabels::label_color_changed(size_t idx)
+void EditLabels::label_colour_changed(size_t idx)
 {
     m_status[idx] = true;
 }
@@ -108,29 +108,29 @@ void EditLabels::update_labels(int /*response*/)
             if(new_name.empty()) {
                 continue;
             }
-            std::string new_color
-                = fwk::gdkcolor_to_rgbcolor(m_colors[i]->get_rgba()).to_string();
+            std::string new_colour
+                = fwk::gdkcolor_to_rgbcolour(m_colours[i]->get_rgba()).to_string();
             if(!undo) {
                 undo = fwk::Application::app()->begin_undo(_("Change Labels"));
             }
 
             if(has_label) {
                 std::string current_name = m_labels[i]->label();
-                std::string current_color = m_labels[i]->color().to_string();
+                std::string current_colour = m_labels[i]->colour().to_string();
 
                 undo->new_command<void>(
-                    boost::bind(&libraryclient::LibraryClient::updateLabel, 
-                                m_lib_client, m_labels[i]->id(), new_name, 
-                                new_color),
-                    boost::bind(&libraryclient::LibraryClient::updateLabel, 
-                                m_lib_client, m_labels[i]->id(), current_name, 
-                                current_color));
+                    boost::bind(&libraryclient::LibraryClient::updateLabel,
+                                m_lib_client, m_labels[i]->id(), new_name,
+                                new_colour),
+                    boost::bind(&libraryclient::LibraryClient::updateLabel,
+                                m_lib_client, m_labels[i]->id(), current_name,
+                                current_colour));
             }
             else {
                 undo->new_command<int>(
-                    boost::bind(&libraryclient::LibraryClient::createLabel, 
-                                m_lib_client, new_name, new_color),
-                    boost::bind(&libraryclient::LibraryClient::deleteLabel, 
+                    boost::bind(&libraryclient::LibraryClient::createLabel,
+                                m_lib_client, new_name, new_colour),
+                    boost::bind(&libraryclient::LibraryClient::deleteLabel,
                                 m_lib_client, _1));
             }
         }
diff --git a/src/niepce/ui/dialogs/editlabels.hpp b/src/niepce/ui/dialogs/editlabels.hpp
index a71ca1c..2b86285 100644
--- a/src/niepce/ui/dialogs/editlabels.hpp
+++ b/src/niepce/ui/dialogs/editlabels.hpp
@@ -44,10 +44,10 @@ public:
     virtual void setup_widget();
 private:
     void label_name_changed(size_t idx);
-    void label_color_changed(size_t idx);
+    void label_colour_changed(size_t idx);
     void update_labels(int /*response*/);
     const eng::Label::List            & m_labels;
-    std::tr1::array<Gtk::ColorButton*, 5> m_colors;
+    std::tr1::array<Gtk::ColorButton*, 5> m_colours;
     std::tr1::array<Gtk::Entry*, 5>   m_entries;
     std::tr1::array<bool, 5>          m_status;
     libraryclient::LibraryClient::Ptr m_lib_client;
diff --git a/src/niepce/ui/librarycellrenderer.cpp b/src/niepce/ui/librarycellrenderer.cpp
index d8380e6..a90df98 100644
--- a/src/niepce/ui/librarycellrenderer.cpp
+++ b/src/niepce/ui/librarycellrenderer.cpp
@@ -164,20 +164,20 @@ int drawFormatEmblem(const Cairo::RefPtr<Cairo::Context> & cr,
 }
 
 void drawLabel(const Cairo::RefPtr<Cairo::Context> & cr, 
-               int right, const fwk::RgbColor * color,
+               int right, const fwk::RgbColour * colour,
                const GdkRectangle & r)
 {
-    DBG_ASSERT(color, "color is NULL");
+    DBG_ASSERT(colour, "colour is NULL");
     const int label_size = 15;
     double x, y;
     x = r.x + r.width - CELL_PADDING - right - CELL_PADDING - label_size;
     y = r.y + r.height - CELL_PADDING - label_size;
-    
+
     cr->rectangle(x, y, label_size, label_size);
     cr->set_source_rgb(1.0, 1.0, 1.0);
     cr->stroke();
     cr->rectangle(x, y, label_size, label_size);
-    Gdk::Cairo::set_source_rgba(cr, fwk::rgbcolor_to_gdkcolor(*color));
+    Gdk::Cairo::set_source_rgba(cr, fwk::rgbcolour_to_gdkcolor(*colour));
     cr->fill();
 }
 
@@ -208,29 +208,29 @@ LibraryCellRenderer::render_vfunc(const Cairo::RefPtr<Cairo::Context>& cr,
 {
     unsigned int xpad = Gtk::CellRenderer::property_xpad();
     unsigned int ypad = Gtk::CellRenderer::property_ypad();
-    
+
     GdkRectangle r = *(cell_area.gobj());
     r.x += xpad;
     r.y += ypad;
-    
+
     eng::LibFile::Ptr file = m_libfileproperty.get_value();
-    
+
     Glib::RefPtr<Gtk::StyleContext> style_context = widget.get_style_context();
-    Gdk::RGBA color;
+    Gdk::RGBA colour;
     if(flags & Gtk::CELL_RENDERER_SELECTED) {
-        color = style_context->get_background_color(Gtk::STATE_FLAG_SELECTED);
+        colour = style_context->get_background_color(Gtk::STATE_FLAG_SELECTED);
     }
     else {
-        color = style_context->get_background_color(Gtk::STATE_FLAG_NORMAL);
+        colour = style_context->get_background_color(Gtk::STATE_FLAG_NORMAL);
     }
-    
-    Gdk::Cairo::set_source_rgba(cr, color);
+
+    Gdk::Cairo::set_source_rgba(cr, colour);
     cr->rectangle(r.x, r.y, r.width, r.height);
     cr->fill();
-    
+
     if(m_drawborder) {
-        color = style_context->get_border_color(Gtk::STATE_FLAG_SELECTED);
-        Gdk::Cairo::set_source_rgba(cr, color);
+        colour = style_context->get_border_color(Gtk::STATE_FLAG_SELECTED);
+        Gdk::Cairo::set_source_rgba(cr, colour);
         cr->set_line_width(1.0);
         cr->rectangle(r.x, r.y, r.width, r.height);
         cr->stroke();
@@ -273,16 +273,16 @@ LibraryCellRenderer::render_vfunc(const Cairo::RefPtr<Cairo::Context>& cr,
             emblem = m_unknown_format_emblem;
             break;
         }
-        
+
         int left = drawFormatEmblem(cr, emblem, r);
         if(m_drawlabel) {
             DBG_ASSERT(m_uiDataProvider, "no UIDataProvider");
             uint32_t label_id = file->label();
             if(label_id != 0) {
-                const fwk::RgbColor * label_color = m_uiDataProvider->colorForLabel(label_id);
-                DBG_ASSERT(label_color, "color not found");
-                if(label_color) {
-                    drawLabel(cr, left, label_color, r);
+                const fwk::RgbColour * label_colour = m_uiDataProvider->colourForLabel(label_id);
+                DBG_ASSERT(label_colour, "colour not found");
+                if(label_colour) {
+                    drawLabel(cr, left, label_colour, r);
                 }
             }
         }
diff --git a/src/niepce/ui/niepcewindow.cpp b/src/niepce/ui/niepcewindow.cpp
index 5d1a32b..4a5edd6 100644
--- a/src/niepce/ui/niepcewindow.cpp
+++ b/src/niepce/ui/niepcewindow.cpp
@@ -390,11 +390,11 @@ void NiepceWindow::on_preferences()
 void NiepceWindow::create_initial_labels()
 {
     // TODO make this parametric from resources
-    m_libClient->createLabel(_("Label 1"), fwk::RgbColor(55769, 9509, 4369).to_string()); /* 217, 37, 17 */
-    m_libClient->createLabel(_("Label 2"), fwk::RgbColor(24929, 55769, 4369).to_string()); /* 97, 217, 17 */
-    m_libClient->createLabel(_("Label 3"), fwk::RgbColor(4369, 50629, 55769).to_string()); /* 17, 197, 217 */
-    m_libClient->createLabel(_("Label 4"), fwk::RgbColor(35209, 4369, 55769).to_string()); /* 137, 17, 217 */
-    m_libClient->createLabel(_("Label 5"), fwk::RgbColor(55769, 35209, 4369).to_string()); /* 217, 137, 17 */
+    m_libClient->createLabel(_("Label 1"), fwk::RgbColour(55769, 9509, 4369).to_string()); /* 217, 37, 17 */
+    m_libClient->createLabel(_("Label 2"), fwk::RgbColour(24929, 55769, 4369).to_string()); /* 97, 217, 17 */
+    m_libClient->createLabel(_("Label 3"), fwk::RgbColour(4369, 50629, 55769).to_string()); /* 17, 197, 217 
*/
+    m_libClient->createLabel(_("Label 4"), fwk::RgbColour(35209, 4369, 55769).to_string()); /* 137, 17, 217 
*/
+    m_libClient->createLabel(_("Label 5"), fwk::RgbColour(55769, 35209, 4369).to_string()); /* 217, 137, 17 
*/
 }
 
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/fwk/base/color.hpp b/src/fwk/base/colour.hpp
similarity index 77%
rename from src/fwk/base/color.hpp
rename to src/fwk/base/colour.hpp
index 6d283a6..8aedd52 100644
--- a/src/fwk/base/color.hpp
+++ b/src/fwk/base/colour.hpp
@@ -1,5 +1,5 @@
 /*
- * niepce - fwk/base/color.hpp
+ * niepce - fwk/base/colour.hpp
  *
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -19,8 +19,8 @@
 
 
 
-#ifndef __FWK_BASE_COLOR_HPP_
-#define __FWK_BASE_COLOR_HPP_
+#ifndef __FWK_BASE_COLOUR_HPP_
+#define __FWK_BASE_COLOUR_HPP_
 
 #include <stdint.h>
 
@@ -29,16 +29,16 @@
 
 namespace fwk {
 
   /** A RgbColor tuple (3 components, 16bpp)
    *  To be used only for UI.
    */
-  class RgbColor
+  class RgbColour
     : public std::tr1::array<uint16_t, 3>
   {
   public:
-    RgbColor(value_type r = 0, value_type g = 0, value_type b = 0);
-    explicit RgbColor(const std::string & );
-    
+    RgbColour(value_type r = 0, value_type g = 0, value_type b = 0);
+    explicit RgbColour(const std::string & );
+
     std::string to_string() const;
   };
 
@@ -29,16 +29,16 @@
 namespace fwk {
 
-  /** A RgbColor tuple (3 components, 16bpp)
+  /** A RgbColour tuple (3 components, 16bpp)
    *  To be used only for UI.
    */